/*
 * This file is part of GtkGraphView.
 *
 * Foobar is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * GtkGraphView is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GtkGraphView. If not, see <https://www.gnu.org/licenses/>.
 */

/**
 * @file gtk-graph-view.h
 * @brief header file for the GtkGraphView Widget
 * @author Mario Hüttel <mario.huettel@gmx.net>
 */

/**
 * @addtogroup GtkGraphView
 * @{
 */

#ifndef __GTK_GRAPH_VIEW_H__
#define __GTK_GRAPH_VIEW_H__

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define GTK_TYPE_GRAPH_VIEW (gtk_graph_view_get_type())

G_DECLARE_FINAL_TYPE(GtkGraphView, gtk_graph_view, GTK, GRAPH_VIEW, GtkBox)

/**
 * @brief Instanciate new GtkGraphView object
 * @return created object
 */
GtkWidget *gtk_graph_view_new();

/**
 * @brief Set the background color of the graph view
 *
 * This is equivalent to setting the "background-color" property
 *
 * @param[in] graph_view GtkGraphView object
 * @param[in] RGBA background color.
 */
void gtk_graph_view_set_background_color(GtkGraphView* graph_view, const GdkRGBA *rgba);

G_END_DECLS

#endif /* __GTK_GRAPH_VIEW_H__ */

/** @} */
